@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2008, Watanabe Lab, School of Media Science,
+ *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
  *	Tokyo University of Technology, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
@@ -37,7 +37,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2008, Watanabe Lab, School of Media Science,
+ *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
  *	Tokyo University of Technology, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
@@ -76,6 +76,8 @@
 #include <FK/Window.h>
 #include <stack>
 
+using namespace std;
+
 enum BVH_NodeType {
 	BVH_ROOT,
 	BVH_JOINT,
@@ -512,7 +514,7 @@ int fk_BVHMotion::getNodeNum(void)
 
 string fk_BVHMotion::getNodeName(int argID)
 {
-	if((unsigned int)argID < 0 || (unsigned int)argID >= nameArray.size()) {
+	if(argID < 0 || (unsigned int)argID >= nameArray.size()) {
 		return "";
 	}
 	return nameArray[argID];
@@ -520,7 +522,7 @@ string fk_BVHMotion::getNodeName(int argID)
 
 fk_Model * fk_BVHMotion::getNodeModel(int argID)
 {
-	if((unsigned int)argID < 0 || (unsigned int)argID >= nodeArray.size()) {
+	if(argID < 0 || (unsigned int)argID >= nodeArray.size()) {
 		return NULL;
 	}
 	return nodeArray[argID];
@@ -568,92 +570,3 @@ int fk_BVHMotion::getFrameLength(void)
 {
 	return length;
 }
-
-/*
-void fk_BVHMotion::convertToD3DXAnimation(fk_D3DXAnimation *argAnim)
-{
-	unsigned int			i, j;
-	fk_Quaternion			q;
-	fk_D3DXFrameAnimation	*cur;
-
-	for(i = 0; i < argAnim->frameData.size(); i++) {
-		argAnim->frameData.at(i)->SetAnimation(NULL);
-	}
-	for(i = 0; i < argAnim->animData.size(); i++) {
-		delete argAnim->animData.at(i);
-	}
-	argAnim->animData.clear();
-
-	for(i = 0; i < (unsigned int)getNodeNum(); i++) {
-		if(getNodeName(i) == "End Site") continue;
-		// cout << "make new animation: " << getNodeName(i) << endl;
-		argAnim->MakeNewAnimation();
-		cur = argAnim->animData.back();
-		cur->SetName(getNodeName(i));
-		cur->SetTransKeyNum(posArray[i].size());
-		cur->SetRotKeyNum(rotArray[i].size());
-		if(posArray[i].size() > rotArray[i].size()) {
-			cur->SetScaleKeyNum(posArray[i].size());
-		} else {
-			cur->SetScaleKeyNum(rotArray[i].size());
-		}
-		for(j = 0; j < (unsigned int)cur->GetTransKeyNum(); j++) {
-			cur->SetTransKey(j, double(int(oneFrameTime*1000.0)*(j+1)));
-			cur->SetTransData(j, posArray[i][j]);
-		}
-		for(j = 0; j < (unsigned int)cur->GetRotKeyNum(); j++) {
-			cur->SetRotKey(j, double(int(oneFrameTime*1000.0)*(j+1)));
-			q.makeEuler(rotArray[i][j]);
-			cur->SetRotData(j, q);
-		}
-		for(j = 0; j < (unsigned int)cur->GetScaleKeyNum(); j++) {
-			cur->SetScaleKey(j, double(int(oneFrameTime*1000.0)*(j+1)));
-			cur->SetScaleData(j, fk_Vector(1.0, 1.0, 1.0));
-		}
-
-		for(j = 0; j < argAnim->frameData.size(); j++) {
-			if(cur->GetName() == argAnim->frameData.at(j)->GetName()) {
-				// cout << "connect: " << cur->GetName() << "->" << argAnim->frameData.at(j)->GetName() << endl;
-				argAnim->frameData.at(j)->SetAnimation(cur);
-				argAnim->frameData.at(j)->SetUpMatrix();
-				break;
-			}
-		}
-	}
-
-	return;
-}
-*/
-
-/*
-void print(fk_D3DXAnimation *argAnim, string argFileName)
-{
-	ofstream		out_file(argFileName.c_str());
-	fk_Quaternion	q;
-	fk_Vector		v;
-
-	for(unsigned int i = 0; i < argAnim->animData.size(); i++) {
-		out_file << argAnim->animData.at(i)->GetName() << "; " << endl;
-		out_file << "[Rot]" << endl;
-		for(int j = 0; j < argAnim->animData.at(i)->GetRotKeyNum(); j++) {
-			out_file << argAnim->animData.at(i)->GetRotKey(j) << ": ";
-			q = argAnim->animData.at(i)->GetRotData(j);
-			out_file << q.s << ", " << q.v.x << ", " << q.v.y << ", " << q.v.z << endl;
-		}
-		out_file << "[Trans]" << endl;
-		for(int j = 0; j < argAnim->animData.at(i)->GetTransKeyNum(); j++) {
-			out_file << argAnim->animData.at(i)->GetTransKey(j) << ": ";
-			v = argAnim->animData.at(i)->GetTransData(j);
-			out_file << v.x << ", " << v.y << ", " << v.z << endl;
-		}
-		out_file << "[Scale]" << endl;
-		for(int j = 0; j < argAnim->animData.at(i)->GetScaleKeyNum(); j++) {
-			out_file << argAnim->animData.at(i)->GetScaleKey(j) << ": ";
-			v = argAnim->animData.at(i)->GetScaleData(j);
-			out_file << v.x << ", " << v.y << ", " << v.z << endl;
-		}
-		out_file << endl;
-	}
-
-}
-*/
