@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2008, Watanabe Lab, School of Media Science,
+ *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
  *	Tokyo University of Technology, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
@@ -37,7 +37,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2008, Watanabe Lab, School of Media Science,
+ *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
  *	Tokyo University of Technology, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
@@ -88,6 +88,8 @@
 
 #include <FK/Error.h>
 
+using namespace std;
+
 static unsigned int		generalID = 1;
 
 fk_GraphicsEngine::fk_GraphicsEngine(void)
@@ -788,26 +790,6 @@ bool fk_GraphicsEngine::GetOGLTextureBindMode(void)
 	return textureDraw->getBindMode();
 }
 
-/*
-bool fk_GraphicsEngine::SnapImage(string argFName, fk_ImageType argType, fk_SnapProcMode argMode)
-{
-	fk_Image	tmpImage;
-
-	if(SnapImage(&tmpImage, argMode) == false) return false;
-
-	switch(argType) {
-	  case FK_IMAGE_PNG:
-		return tmpImage.writePNG(argFName, false);
-	  case FK_IMAGE_JPG:
-		return tmpImage.writeJPG(argFName);
-	  case FK_IMAGE_BMP:
-	  default:
-		break;
-	}
-	return tmpImage.writeBMP(argFName);
-}
-*/
-
 bool fk_GraphicsEngine::SnapImage(fk_Image *argImage, fk_SnapProcMode argMode)
 {
 	int	wCount, hCount;
@@ -840,9 +822,7 @@ bool fk_GraphicsEngine::SnapImage(fk_Image *argImage, fk_SnapProcMode argMode)
 	return true;
 }
 
-void fk_GraphicsEngine::GetPickData(fk_PickData *argPickData,
-									int argPixSize,
-									int argMouseX, int argMouseY)
+void fk_GraphicsEngine::GetPickData(fk_PickData *argPickData, int argPixSize, int argMouseX, int argMouseY)
 {
 	GLint			hits;
 	unsigned int	ii;
@@ -851,7 +831,7 @@ void fk_GraphicsEngine::GetPickData(fk_PickData *argPickData,
 
 	if(argPickData == (fk_PickData *)NULL) return;
 
-	// SetPickViewPort(argPixSize, argMouseX, argMouseY);
+	SetPickViewPort(argPixSize, argMouseX, argMouseY);
 	RecalcModelView();
 	DrawObjs(true);
 
