@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2008, Watanabe Lab, School of Media Science,
+ *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
  *	Tokyo University of Technology, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
@@ -37,7 +37,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2008, Watanabe Lab, School of Media Science,
+ *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
  *	Tokyo University of Technology, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
@@ -84,6 +84,8 @@
 
 #include <FK/Error.h>
 
+using namespace std;
+
 // ★★★★★ Direct3D オブジェクト
 static LPDIRECT3D9			g_lpD3D = NULL;
 static LPDIRECT3DDEVICE9	g_lpD3DDEV = NULL;
@@ -1213,7 +1215,7 @@ void fk_GraphicsEngine::GetPickData(fk_PickData *argPickData,
 
 	if(argPickData == (fk_PickData *)NULL) return;
 
-	// SetPickViewPort(argPixSize, argMouseX, argMouseY);
+	SetPickViewPort(argPixSize, argMouseX, argMouseY);
 	RecalcModelView(true);
 	DrawObjs(true);
 
