@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2008, Watanabe Lab, School of Media Science,
+ *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
  *	Tokyo University of Technology, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
@@ -37,7 +37,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2008, Watanabe Lab, School of Media Science,
+ *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
  *	Tokyo University of Technology, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
@@ -75,6 +75,8 @@
 #include <FK/Error.h>
 #include <libpng/png.h>
 
+using namespace std;
+
 extern "C" {
 	#define XMD_H
 	#ifdef WIN32
@@ -183,7 +185,7 @@ fk_ImageStatus fk_Image::LoadBmpFile(const string argFName)
 		rgbQuad.clear();
 	}
 
-	tmpSize = GetOneBufferSize(paletteSize, bmpType, bmpSize.w);
+	tmpSize = GetOneBufferSize(bmpType, bmpSize.w);
 	if(tmpSize < 0) return FK_IMAGE_DATAERROR;
 
 	tmpBuffer.resize(tmpSize);
@@ -241,7 +243,7 @@ fk_ImageStatus fk_Image::LoadBmpData(fk_ImType *argBuffer)
 		tmpImageBuf = argBuffer + 54;
 	}
 
-	tmpSize = GetOneBufferSize(paletteSize, bmpType, bmpSize.w);
+	tmpSize = GetOneBufferSize(bmpType, bmpSize.w);
 	if(tmpSize < 0) return FK_IMAGE_DATAERROR;
 
 	for(y = bmpSize.h - 1, count = 0; y >= 0; y--, count++) {
