@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2008, Watanabe Lab, School of Media Science,
+ *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
  *	Tokyo University of Technology, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
@@ -37,7 +37,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2008, Watanabe Lab, School of Media Science,
+ *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
  *	Tokyo University of Technology, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
@@ -83,9 +83,15 @@
 #include <FK/VRMLParser.h>
 #include <FK/MQOParser.h>
 #include <FK/VRMLOut.h>
+#include <FK/STLOut.h>
+#include <FK/DXFOut.h>
+#include <FK/MQOOut.h>
 #include <FK/IFSetHandle.h>
+
 #include <algorithm>
 
+using namespace std;
+
 fk_IndexFaceSet::fk_IndexFaceSet(void)
 {
 	setObjectType(FK_INDEXFACESET);
@@ -166,7 +172,7 @@ bool fk_IndexFaceSet::Init(int argTNum, int argPNum, int argVNum)
 
 bool fk_IndexFaceSet::MakeMesh(vector<fk_Vector> *vData,
 							   vector< vector<int> > *lIndex,
-							   vector<int> *mateIDSet, bool argSolidFlag)
+							   vector<int> *mateIDSet, bool)
 {
 	int				i, j, pNum;
 	vector<int>		tmpP;
@@ -944,22 +950,42 @@ bool fk_IndexFaceSet::writeVRMLFile(string argFileName,
 	return retFlg;
 }
 
-bool fk_IndexFaceSet::writeVRMLFile(string argFileName,
-									vector<double> *argTime,
-									vector<fk_Vector> *argPos,
-									fk_Material *argMaterial, bool triFlag)
+bool fk_IndexFaceSet::writeVRMLFile(string,
+									vector<double> *,
+									vector<fk_Vector> *,
+									fk_Material *, bool)
 {
 	return true;
 }
 
 bool fk_IndexFaceSet::writeSTLFile(string argFileName)
 {
-	return true;
+	fk_STLOut		*stlOut = new fk_STLOut(this);
+	bool			retFlg;
+
+	retFlg = stlOut->writeSTLFile(argFileName);
+	delete stlOut;
+	return retFlg;
 }
 
 bool fk_IndexFaceSet::writeDXFFile(string argFileName, bool argTriFlg)
 {
-	return true;
+	fk_DXFOut		*dxfOut = new fk_DXFOut(this);
+	bool			retFlg;
+
+	retFlg = dxfOut->writeDXFFile(argFileName, argTriFlg);
+	delete dxfOut;
+	return retFlg;
+}
+
+bool fk_IndexFaceSet::writeMQOFile(string argFileName)
+{
+	fk_MQOOut		*mqoOut = new fk_MQOOut(this);
+	bool			retFlg;
+
+	retFlg = mqoOut->writeMQOFile(argFileName);
+	delete mqoOut;
+	return retFlg;
 }
 
 void fk_IndexFaceSet::makeBlock(double argX, double argY, double argZ)
