@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2008, Watanabe Lab, School of Media Science,
+ *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
  *	Tokyo University of Technology, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
@@ -37,7 +37,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2008, Watanabe Lab, School of Media Science,
+ *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
  *	Tokyo University of Technology, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
@@ -75,6 +75,8 @@
 #include <FK/IFSTexture.h>
 #include <FK/Tree.h>
 
+using namespace std;
+
 class _fk_MQOPropertyList : public fk_TreeBaseObject {
 public:
 	string		property;
@@ -214,7 +216,7 @@ bool fk_MQOParser::CheckFile(const string &argFileName)
 }
 
 
-bool fk_MQOParser::CheckData(unsigned char *argBuffer)
+bool fk_MQOParser::CheckData(unsigned char *)
 {
 	return true;
 }
