@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2008, Watanabe Lab, School of Media Science,
+ *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
  *	Tokyo University of Technology, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
@@ -37,7 +37,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2008, Watanabe Lab, School of Media Science,
+ *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
  *	Tokyo University of Technology, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
@@ -74,6 +74,8 @@
 #include <FK/Matrix.h>
 #include <FK/Error.h>
 
+using namespace std;
+
 ///////////// inline 関数群 
 
 // 0 との比較関数 (実数用) 
@@ -598,6 +600,7 @@ fk_Matrix::fk_Matrix(void)
 
 // コピーコンストラクタ 
 fk_Matrix::fk_Matrix(const fk_Matrix &argMat)
+	: fk_UnitMatrix()
 {
 	CopyMatrix(m, argMat.m);
 }
