@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2008, Watanabe Lab, School of Media Science,
+ *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
  *	Tokyo University of Technology, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
@@ -37,7 +37,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2008, Watanabe Lab, School of Media Science,
+ *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
  *	Tokyo University of Technology, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
@@ -80,6 +80,8 @@
 #include <FK/Shell.h>
 #include <FK/Error.h>
 
+using namespace std;
+
 fk_Modify::fk_Modify(fk_DataBase *argDB)
 	: fk_Operation(argDB)
 {
@@ -850,7 +852,7 @@ void fk_Modify::makeSphere(int argDiv, double argRadius)
 	vector<fk_Vector>		VecArray;
 	vector<int>				IDArray;
 	vector< vector<int> >	IFArray;
-	register int			i, j, index, index2;
+	int						i, j, index, index2;
 	vector<double>			xz_radius;
 	double					theta1, theta2;
 
