@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2008, Watanabe Lab, School of Media Science,
+ *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
  *	Tokyo University of Technology, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
@@ -37,7 +37,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2008, Watanabe Lab, School of Media Science,
+ *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
  *	Tokyo University of Technology, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
@@ -80,6 +80,8 @@
 #include <FK/Shell.h>
 #include <FK/Error.h>
 
+using namespace std;
+
 fk_Operation::fk_Operation(fk_DataBase *argDB)
 {
 	SetDataBase(argDB);
@@ -1734,12 +1736,12 @@ void fk_Operation::setTesselateMode(bool argMode)
 	tesselateMode = argMode;
 
 	if(tesselateMode == true) {
-		curL = getNextL(NULL);
-		while(curL != NULL) {
+		for(curL = getNextL(NULL); curL != NULL; curL = getNextL(curL)) {
 			curL->setTesselateMode(true);
 			curL->isTesselated();
-			curL = getNextL(curL);
 		}
+	} else {
+		deleteAllTesselateData();
 	}
 
 	return;
@@ -1752,11 +1754,10 @@ bool fk_Operation::getTesselateMode(void)
 
 void fk_Operation::deleteAllTesselateData(void)
 {
-	fk_Loop			*curL = getNextL(NULL);
+	fk_Loop			*curL;
 
-	while(curL != NULL) {
+	for(curL = getNextL(NULL); curL != NULL; curL = getNextL(curL)) {
 		curL->setTesselateMode(false);
-		curL = getNextL(curL);
 	}
 	return;
 }
