@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2008, Watanabe Lab, School of Media Science,
+ *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
  *	Tokyo University of Technology, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
@@ -37,7 +37,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2008, Watanabe Lab, School of Media Science,
+ *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
  *	Tokyo University of Technology, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
@@ -84,6 +84,8 @@
 #include <FL/fl_ask.H>
 #include <FL/Fl_File_Chooser.H>
 
+using namespace std;
+
 static const int			FK_SHAPE_BLACK = 0;
 static const int			FK_SHAPE_RED = 1;
 static const int			FK_SHAPE_GREEN = 2;
@@ -93,8 +95,8 @@ static const int			FK_SHAPE_BLUEGREEN = 5;
 static const int			FK_SHAPE_MAGENTA = 6;
 static const int			FK_SHAPE_WHITE = 7;
 
-static fk_ShapeGUIMenuItem	globalMenuStatus;
-static bool					globalMenuValue;
+static fk_ShapeGUIMenuItem	globalMenuStatus = FK_SV_GUI_NONE;
+static bool					globalMenuValue = true;
 
 class fk_GUI_ {
 public:
@@ -110,35 +112,37 @@ public:
 
 
 Fl_Menu_Item menuTable[] = {
-	{"&File", FL_ALT + 'f', 0, 0, FL_SUBMENU},
-	{"&WRLOpen", FL_ALT + 'w', 0},
-	{"S&TLOpen", FL_ALT + 't', 0},
-	{"D&XFOpen", FL_ALT + 'x', 0},
-	{"WRL&Save", FL_ALT + 'w'},
-	//	{"&STLSave", FL_ALT + 's'},
-	{"&ImageSnap", FL_ALT + 'i'},
-	{"&Quit", FL_ALT + 'q'},
-	{0},
-	{"&DrawStatus", FL_ALT + 'd', 0, 0, FL_SUBMENU},
-	{"&PolyDraw", FL_ALT + 'p', 0, 0, FL_MENU_TOGGLE | FL_MENU_VALUE},
-	{"&EdgeDraw", FL_ALT + 'e', 0, 0, FL_MENU_TOGGLE | FL_MENU_VALUE},
-	{"&VertexDraw", FL_ALT + 'v', 0, 0, FL_MENU_TOGGLE},
-	{"&AxisDraw", FL_ALT + 'a', 0, 0, FL_MENU_TOGGLE | FL_MENU_VALUE},
-	{"LightRotate", 0, 0, 0, FL_MENU_TOGGLE},
-	{0},
-	{"Material", 0, 0, 0, FL_SUBMENU},
-	{"Ambient", 0},
-	{"Diffuse", 0},
-	{"Specular", 0},
-	{"Emission", 0},
-	{"Shininess", 0},
-	{"VertexColor", 0},
-	{"EdgeColor", 0},
-	{0},
-	{0}
+	{"&File",		FL_ALT + 'f',	0, 0, FL_SUBMENU, 0, 0, 0, 0},
+	{"&WRLOpen",	FL_ALT + 'w',	0, 0, 0, 0, 0, 0, 0},
+	{"S&TLOpen",	FL_ALT + 't',	0, 0, 0, 0, 0, 0, 0},
+	{"D&XFOpen",	FL_ALT + 'x',	0, 0, 0, 0, 0, 0, 0},
+	{"WRL&Save",	FL_ALT + 'w',	0, 0, 0, 0, 0, 0, 0},
+	{"&ImageSnap",	FL_ALT + 'i',	0, 0, 0, 0, 0, 0, 0},
+	{"&Quit",		FL_ALT + 'q',	0, 0, 0, 0, 0, 0, 0},
+	{0,				0,				0, 0, 0, 0, 0, 0, 0},
+	{"&DrawStatus",	FL_ALT + 'd',	0, 0, FL_SUBMENU, 0, 0, 0, 0},
+	{"&PolyDraw",	FL_ALT + 'p',	0, 0, FL_MENU_TOGGLE | FL_MENU_VALUE,
+	 0, 0, 0, 0},
+	{"&EdgeDraw",	FL_ALT + 'e',	0, 0, FL_MENU_TOGGLE | FL_MENU_VALUE,
+	 0, 0, 0, 0},
+	{"&VertexDraw",	FL_ALT + 'v',	0, 0, FL_MENU_TOGGLE, 0, 0, 0, 0},
+	{"&AxisDraw",	FL_ALT + 'a',	0, 0, FL_MENU_TOGGLE | FL_MENU_VALUE,
+	 0, 0, 0, 0},
+	{"LightRotate",	0,				0, 0, FL_MENU_TOGGLE, 0, 0, 0, 0},
+	{0,				0,				0, 0, 0, 0, 0, 0, 0},
+	{"Material",	0,				0, 0, FL_SUBMENU, 0, 0, 0, 0},
+	{"Ambient",		0,				0, 0, 0, 0, 0, 0, 0},
+	{"Diffuse",		0,				0, 0, 0, 0, 0, 0, 0},
+	{"Specular",	0,				0, 0, 0, 0, 0, 0, 0},
+	{"Emission",	0,				0, 0, 0, 0, 0, 0, 0},
+	{"Shininess",	0,				0, 0, 0, 0, 0, 0, 0},
+	{"VertexColor",	0,				0, 0, 0, 0, 0, 0, 0},
+	{"EdgeColor",	0,				0, 0, 0, 0, 0, 0, 0},
+	{0,				0,				0, 0, 0, 0, 0, 0, 0},
+	{0,				0,				0, 0, 0, 0, 0, 0, 0}
 };
 
-static void LocalMenuToggle(Fl_Widget *argW, void *dummy)
+static void LocalMenuToggle(Fl_Widget *argW, void *)
 {
 	Fl_Menu_			*mw = (Fl_Menu_ *)argW;
 	const Fl_Menu_Item	*mItem = mw->mvalue();
@@ -542,7 +546,7 @@ void fk_ShapeViewer::SetAllMaterial(void)
 	return;
 }
 
-void fk_ShapeViewer::SetSceneFlg(fk_ShapeGUIMenuItem argStatus, bool argFlg)
+void fk_ShapeViewer::SetSceneFlg(fk_ShapeGUIMenuItem argStatus)
 {
 	switch(argStatus) {
 	  case FK_SV_GUI_POLYDRAW:
@@ -856,7 +860,7 @@ bool fk_ShapeViewer::MenuSelect(void)
 	  case FK_SV_GUI_POLYDRAW:
 	  case FK_SV_GUI_EDGEDRAW:
 	  case FK_SV_GUI_VERTEXDRAW:
-		SetSceneFlg(globalMenuStatus, globalMenuValue);
+		SetSceneFlg(globalMenuStatus);
 		break;
 
 	  case FK_SV_GUI_LIGHTROTATE:
@@ -1456,7 +1460,7 @@ double fk_ShapeViewer::getPointSize(int argID)
 	return model->getWidth();
 }
 
-bool fk_ShapeViewer::shapeProcess(fk_Solid *argSolid)
+bool fk_ShapeViewer::shapeProcess(fk_Solid *)
 {
 	return true;
 }
